@@ -6,6 +6,7 @@ import os
 import time
 import array
 import StringIO
+import platform
 import xpa
 
 """
@@ -20,28 +21,41 @@ ds9.py connects python and ds9 via the xpa messaging system:
 """
 
 # pyds9 version
-__version__ = '1.6'
+__version__ = '1.7'
 
+# try to be a little bit neat with global parameters
+ds9Globals = {}
+
+# platform-specific parameters
+ds9Globals["ulist"] = platform.uname()
+if ds9Globals["ulist"][0] == 'Windows':
+    ds9Globals["progs"] = ['xpans.exe', 'ds9.exe']
+else:
+    ds9Globals["progs"] = ['xpans', 'ds9']
+
+# load pyfits, if available
 try:
     from astropy.io import fits as pyfits
-    _have_pyfits = 1
+    ds9Globals["pyfits"] = 1
 except:
     try:
         import pyfits
         if pyfits.__version__ >=  '2.2':
-            _have_pyfits = 2
+            ds9Globals["pyfits"] = 2
         else:
-            _have_pyfits = 0
+            ds9Globals["pyfits"] = 0
     except:
-        _have_pyfits = 0
+        ds9Globals["pyfits"] = 0
 
+# load numpy, if available
 try:
     import numpy
-    _have_numpy = 1
+    ds9Globals["numpy"] = 1
 except:
-    _have_numpy = 0
+    ds9Globals["numpy"] = 0
 
-if _have_numpy:
+# numpy-dependent routines
+if ds9Globals["numpy"]:
     def _bp2np(bitpix):
         """
         Convert FITS bitpix to numpy datatype
@@ -79,19 +93,21 @@ def ds9_xpans():
     of ds9 is displayed.
     """
     if xpa.xpaaccess("xpans", None, 1) == None:
-        _cmd = None
-        # look in install directories
+        _cmd = False
+        # look in install directories for xpans
         for _dir in sys.path:
-            _fname = os.path.join(_dir, "xpans")
+            _fname = os.path.join(_dir, ds9Globals["progs"][0])
             if os.path.exists(_fname):
-                _cmd = _fname + " -e &"
+                _cmd = True
+                break
         # look in development directory
         if not _cmd:
-            _fname = './xpa-2.1.14/xpans'
+            _fname = './xpa/' + ds9Globals["progs"][0]
             if os.path.exists(_fname):
-                _cmd = _fname + " -e &"
+                _cmd = True
         if _cmd:
-            os.system(_cmd)
+            # start up xpans
+            subprocess.Popen([_fname, "-e"])
             # if ds9 is already running, issue a warning
             pslist = commands.getoutput('ps -A')
             if 'ds9' in pslist:
@@ -264,7 +280,7 @@ class ds9(object):
                     args = list(start)
                 except TypeError:       # Not an iterable object
                     args = []
-            self.pid = subprocess.Popen(['ds9', '-title', target] + args)
+            self.pid = subprocess.Popen([ds9Globals["progs"][1], '-title', target] + args)
             for i in range(wait):
                 tlist = xpa.xpaaccess(target, None, 1024)
                 if tlist: break
@@ -377,7 +393,7 @@ class ds9(object):
 
         """
 	self._selftest()
-        if _have_numpy and type(buf) == numpy.ndarray:
+        if ds9Globals["numpy"] and type(buf) == numpy.ndarray:
                 s = buf.tostring()
         elif type(buf) == array.array:
             s = buf.tostring()
@@ -406,7 +422,7 @@ class ds9(object):
         x = xpa.xpaaccess(self.id, None, 1)
 	return x[0]
             
-    if _have_pyfits:
+    if ds9Globals["pyfits"]:
         def get_pyfits(self):
             """
             :rtype: pyfits hdulist
@@ -446,10 +462,10 @@ class ds9(object):
             while a return value of 0 indicates a failure.
             """
 	    self._selftest()
-            if not _have_pyfits:
+            if not ds9Globals["pyfits"]:
                 raise ValueError, 'set_pyfits not defined (pyfits not found)'
             if type(hdul) != pyfits.HDUList:
-                if _have_pyfits == 1:
+                if ds9Globals["pyfits"] == 1:
                     raise ValueError, 'requires pyfits.HDUList as input'
                 else:
                     raise ValueError, 'requires astropy.HDUList as input'
@@ -472,7 +488,7 @@ class ds9(object):
             """
             raise ValueError, 'set_pyfits not defined (pyfits not found)'
 
-    if _have_numpy:
+    if ds9Globals["numpy"]:
         def get_arr2np(self):
             """
             :rtype: numpy array
@@ -584,7 +600,7 @@ if __name__ == '__main__':
     while ds9_targets("pytest") == None:
         if tries == 0:
             print "starting ds9 ..."
-            os.system("ds9 -title pytest &")
+            subprocess.Popen([ds9Globals["progs"][1], '-title', 'pytest'])
             print "\nwaiting for ds9 to be available ",
         elif tries == 10:
             raise ValueError, "tired of waiting for ds9!"
@@ -608,7 +624,7 @@ if __name__ == '__main__':
         d.set(cmd)
         print "sent file=%s dims=(%s,%s) bitpix=%s" % (d.get("file"),d.get("fits width"),d.get("fits height"),d.get("fits bitpix"))
 
-        if _have_numpy:
+        if ds9Globals["numpy"]:
             print "\ntesting numpy support ..."
             a = d.get_arr2np()
             print "reading nparray: shape=%s dtype=%s" % (a.shape, a.dtype)
@@ -625,8 +641,8 @@ if __name__ == '__main__':
         else:
             print "\nskipping numpy test ..."
 
-        if _have_pyfits:
-            print "\ntesting pyfits support (%d) ..." % _have_pyfits
+        if ds9Globals["pyfits"]:
+            print "\ntesting pyfits support (%d) ..." % ds9Globals["pyfits"]
             hdul = d.get_pyfits()
             print hdul.info()
             i = hdul[0].data
