@@ -74,14 +74,14 @@ static char *XPACmdParseNames(lbuf, ntokens)
 #ifdef ANSI_FUNC
 static int 
 XPAReceiveNSConnect (void *client_data, void *call_data, char *paramlist,
-	       char *buf, int len)
+	       char *buf, size_t len)
 #else
 static int XPAReceiveNSConnect(client_data, call_data, paramlist, buf, len)
      void *client_data;
      void *call_data;
      char *paramlist;
      char *buf;
-     int len;
+     size_t len;
 #endif
 {
   XPA xpa = (XPA)call_data;
@@ -120,14 +120,14 @@ static int XPAReceiveNSConnect(client_data, call_data, paramlist, buf, len)
 #ifdef ANSI_FUNC
 static int 
 XPAReceiveNSDisconnect (void *client_data, void *call_data, char *paramlist,
-	       char *buf, int len)
+	       char *buf, size_t len)
 #else
 static int XPAReceiveNSDisconnect(client_data, call_data, paramlist, buf, len)
      void *client_data;
      void *call_data;
      char *paramlist;
      char *buf;
-     int len;
+     size_t len;
 #endif
 {
   XPA xpa = (XPA)call_data;
@@ -175,14 +175,14 @@ static int XPAReceiveNSDisconnect(client_data, call_data, paramlist, buf, len)
 #ifdef ANSI_FUNC
 static int 
 XPAReceiveEnv (void *client_data, void *call_data, char *paramlist,
-	       char *buf, int len)
+	       char *buf, size_t len)
 #else
 static int XPAReceiveEnv(client_data, call_data, paramlist, buf, len)
      void *client_data;
      void *call_data;
      char *paramlist;
      char *buf;
-     int len;
+     size_t len;
 #endif
 {
   XPA xpa = (XPA)call_data;
@@ -230,14 +230,14 @@ static int XPAReceiveEnv(client_data, call_data, paramlist, buf, len)
 #ifdef ANSI_FUNC
 static int 
 XPASendEnv (void *client_data, void *call_data, char *paramlist,
-	    char **buf, int *len)
+	    char **buf, size_t *len)
 #else
 static int XPASendEnv(client_data, call_data, paramlist, buf, len)
      void *client_data;
      void *call_data;
      char *paramlist;
      char **buf;
-     int *len;
+     size_t *len;
 #endif
 {
   int tlen;
@@ -272,14 +272,14 @@ static int XPASendEnv(client_data, call_data, paramlist, buf, len)
 #ifdef ANSI_FUNC
 static int 
 XPAReceiveReserved (void *client_data, void *call_data, char *paramlist,
-		    char *buf, int len)
+		    char *buf, size_t len)
 #else
 static int XPAReceiveReserved(client_data, call_data, paramlist, buf, len)
      void *client_data;
      void *call_data;
      char *paramlist;
      char *buf;
-     int len;
+     size_t len;
 #endif
 {
   char *cmd = (char *)client_data;
@@ -312,14 +312,14 @@ static int XPAReceiveReserved(client_data, call_data, paramlist, buf, len)
 #ifdef ANSI_FUNC
 static int 
 XPASendHelp (void *client_data, void *call_data, char *paramlist,
-	     char **buf, int *len)
+	     char **buf, size_t *len)
 #else
 static int XPASendHelp(client_data, call_data, paramlist, buf, len)
      void *client_data;
      void *call_data;
      char *paramlist;
      char **buf;
-     int *len;
+     size_t *len;
 #endif
 {
   XPA xpa = (XPA)call_data;
@@ -402,14 +402,14 @@ static int XPASendHelp(client_data, call_data, paramlist, buf, len)
 #ifdef ANSI_FUNC
 static int 
 XPASendVersion (void *client_data, void *call_data, char *paramlist,
-	     char **buf, int *len)
+	     char **buf, size_t *len)
 #else
 static int XPASendVersion(client_data, call_data, paramlist, buf, len)
      void *client_data;
      void *call_data;
      char *paramlist;
      char **buf;
-     int *len;
+     size_t *len;
 #endif
 {
   XPA xpa = (XPA)call_data;
@@ -647,14 +647,14 @@ XPACmd XPACmdLookup(xpa, lbuf, lp)
 #ifdef ANSI_FUNC
 int 
 XPAReceiveCommands (void *client_data, void *call_data, char *paramlist,
-		    char *buf, int len)
+		    char *buf, size_t len)
 #else
 int XPAReceiveCommands(client_data, call_data, paramlist, buf, len)
      void *client_data;
      void *call_data;
      char *paramlist;
      char *buf;
-     int len;
+     size_t len;
 #endif
 {
   XPA xpa = (XPA)call_data;
@@ -826,14 +826,14 @@ done:
 #ifdef ANSI_FUNC
 int 
 XPASendCommands (void *client_data, void *call_data, char *paramlist,
-		 char **buf, int *len)
+		 char **buf, size_t *len)
 #else
 int XPASendCommands(client_data, call_data, paramlist, buf, len)
      void *client_data;
      void *call_data;
      char *paramlist;
      char **buf;
-     int *len;
+     size_t *len;
 #endif
 {
   XPA xpa = (XPA)call_data;
@@ -1142,14 +1142,14 @@ int XPACmdDel(xpa, cmd)
 #ifdef ANSI_FUNC
 int 
 XPACmdInternalReceive (void *client_data, void *call_data,
-		       char *paramlist, char *buf, int len)
+		       char *paramlist, char *buf, size_t len)
 #else
 int XPACmdInternalReceive(client_data, call_data, paramlist, buf, len)
      void *client_data;
      void *call_data;
      char *paramlist;
      char *buf;
-     int len;
+     size_t len;
 #endif
 {
   XPA xpa = (XPA)call_data;
@@ -1175,14 +1175,14 @@ int XPACmdInternalReceive(client_data, call_data, paramlist, buf, len)
 #ifdef ANSI_FUNC
 int 
 XPACmdInternalSend (void *client_data, void *call_data,
-		    char *paramlist, char **buf, int *len)
+		    char *paramlist, char **buf, size_t *len)
 #else
 int XPACmdInternalSend(client_data, call_data, paramlist, buf, len)
      void *client_data;
      void *call_data;
      char *paramlist;
      char **buf;
-     int *len;
+     size_t *len;
 #endif
 {
   XPA xpa = (XPA)call_data;
